package org.xbib.event.clock;

import java.util.concurrent.Callable;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.xbib.event.Event;
import org.xbib.event.common.EventManager;

public class ClockEventService implements Callable<Boolean> {

    private static final Logger logger = Logger.getLogger(ClockEventService.class.getName());

    private final ClockEventManagerService clockEventManagerService;

    private final String name;

    public ClockEventService(ClockEventManagerService clockEventManagerService,
                             String name) {
        this.clockEventManagerService = clockEventManagerService;
        this.name = name;
    }

    @Override
    public Boolean call() {
        try {
            if (clockEventManagerService.getSuspended().contains(name)) {
                logger.log(Level.FINE, "clock event " + name + " suspended");
                return false;
            } else {
                Event clockEvent = EventManager.eventBuilder()
                        .setType("clock")
                        .build();
                clockEventManagerService.publish(clockEvent);
                return true;
            }
        } catch (Throwable t) {
            logger.log(Level.WARNING, t.getMessage(), t);
            return false;
        }
    }
}
