package org.xbib.event.path;

import org.junit.jupiter.api.Test;
import org.xbib.event.PathEvent;
import org.xbib.event.common.EventManager;
import org.xbib.event.common.PathEventImpl;
import org.xbib.settings.Settings;

import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.logging.Level;
import java.util.logging.Logger;

public class PathEventManagerTest {

    private static final Logger logger = Logger.getLogger(PathEventManagerTest.class.getName());

    @Test
    public void testPathEvents() throws IOException, InterruptedException {
        Path path = Files.createTempDirectory("testpath");
        TestPathEventConsumer consumer = new TestPathEventConsumer();
        Settings settings = Settings.settingsBuilder()
                .put("event.path.testpathevent.enabled", "true")
                .put("event.path.testpathevent.path", path.toString())
                .build();
        EventManager eventManager = EventManager.builder()
                .setSettings(settings)
                .register(consumer)
                .build();
        Path testTxt = path.resolve("incoming").resolve("test.txt");
        try (BufferedWriter bufferedWriter = Files.newBufferedWriter(testTxt)) {
            bufferedWriter.write("Hello");
        }
        Thread.sleep(2000L);
        eventManager.shutdown();
        // extra destroy to clean up test
        eventManager.getPathEventManagerService().destroy();
    }

    @Test
    public void testExtendedPathEvent() throws Exception {
        Path path = Files.createTempDirectory("testpath");
        TestPathEventConsumer consumer = new TestPathEventConsumer();
        Settings settings = Settings.settingsBuilder()
                .put("event.path.testpathevent.enabled", "true")
                .put("event.path.testpathevent.path", path.toString())
                .put("event.path.testpathevent.type", "path-ext")
                .build();
        EventManager eventManager = EventManager.builder()
                .setSettings(settings)
                .register("path-ext", PathExtEvent.class)
                .register(consumer)
                .build();
        Path testTxt = path.resolve("incoming").resolve("test.txt");
        try (BufferedWriter bufferedWriter = Files.newBufferedWriter(testTxt)) {
            bufferedWriter.write("Hello");
        }
        Thread.sleep(2000L);
        eventManager.shutdown();
        // extra destroy to clean up test
        eventManager.getPathEventManagerService().destroy();
    }

    public static class PathExtEvent extends PathEventImpl implements PathEvent {

        public PathExtEvent(EventManager.EventBuilder builder) {
            super(builder);
            logger.log(Level.INFO, "I'm the path ext event");
        }
    }
}
